<!DOCTYPE html>
<html>
  <head>
    <!-- Bootstrap -->
    <link href="/static/css/bootstrap.min.css" rel="stylesheet">
    <link href="/static/css/custom.css" rel="stylesheet">
  </head>
  <body>
    <div class="wrapper">
      <div class="navbar navbar-inverse">
        <div class="navbar-inner container">
          <a class="brand" href="/">eukalypse-now</a>
          <ul class="nav">
          </ul>
        </div>
      </div>
      <div class="container">
  	  {% block base_content %}{% endblock %}
  	  </div>
      <footer class="footer">
      <div class="container">
          eukylapse and eukalypse-now are <a href="https://github.com/kinkerl/eukalypse_now">Open Source Software</a><br/>
          Code licensed under a three clause <a href="https://raw.github.com/kinkerl/eukalypse_now/master/LICENSE">BSD License</a><br/>
          <a href="http://eukalypse_now.readthedocs.org">Documentation</a> | <a href="https://github.com/kinkerl/eukalypse_now/issues?state=open">Issues</a>    
      </div>
    </footer>
    </div>
  	
      <script src="http://code.jquery.com/jquery-latest.js"></script>
      <script src="/static/js/bootstrap.min.js"></script>
        <script>
        jQuery(document).ready(function(){
        jQuery('.ajaxcall').click(function(e){
            e.preventDefault();
            
            var ident = jQuery(this).data('ident');
            
            jQuery.ajax({
                url: jQuery(this).attr('href'),
                dataType: 'json',
                success: function(){
                    var anchor = jQuery('.anchor[data-ident=' + ident + ']').attr('name');
                    window.location.href = window.location.href.split('#')[0] + "#" + anchor;
                    window.location.reload(true);
                },
                complete: function(){},
                error: function() {}
            });
        });
        });
        </script>
  
  </body>
</html>
