html, body { height: 100%; }

.wrapper {
    min-height: 100%;
    position: relative;
    width: 100%;
}

.wrapper > .container {
    padding-bottom: 220px;
}

.footer {
  padding: 70px 0;
  margin-top: 70px;
  border-top: 1px solid #e5e5e5;
  background-color: #f5f5f5;
  position: absolute;
  bottom: 0;
  width: 100%;
}
