<h1>{{testrun}}</h1>

<a href="{{SITE_URL}}{{testrun.get_absolute_url}}">web protocoll</a><br/>
<ul>
{% for testresult in testrun.testresult.all %}
    <li>{{testresult.test.identifier}}
    {% if testresult.error %}
        <span style="color: red">ERROR</span>
    {% else %}
        <span style="color: green">clean</span>
    {% endif %}
    </li>
{% endfor %}
</ul>
